import unittest, Apse

# test cases lifted from the perl module
class ApseTest(unittest.TestCase):

	def testBasic(self):
		word = "abcdefghijklmnopqrstuvxzy"
		numb = "0123456789"
		apx = Apse.Approx(word, edit=2, dlt=2)
		self.assertEqual(apx.pattern, word)
		self.assertEqual(apx.match(word), word)
		self.assertEqual(apx.match(numb), None)
		self.assertEqual(apx.dist(word), 0)

	def testDist(self):
		apx = Apse.Approx("abc")
		self.assertEqual(apx.dist("abc"), 0)
		self.assertEqual(apx.dist("abd"), 1)
		self.assertEqual(apx.dist("ade"), 2)
		self.assertEqual(apx.dist("def"), 3)	
		self.assertEqual(apx.dist("x"), 3)	
		
	def testMatch(self):
		words = "aberrant accelerate appeal dispel dispute erlangen felicity foobar gibberish hyperbola hyphen iterate legerdemain merlin mermaid nouveau cameau oatmeal park parlance Pearl pearl perk petal superappeal superlative supple twirl xyzzy zealous".split()

 		# default is 10% match sensitivity
		apx = Apse.Approx("perl")
		test_words = "appeal dispel erlangen hyperbola merlin parlance pearl perk superappeal superlative".split()
		self.assertEqual(apx.match(words), test_words)

		# no insertions allowed
		apx = Apse.Approx("perl", ins=0)
		test_words = "appeal dispel erlangen hyperbola merlin parlance perk superappeal superlative".split()
		self.assertEqual(apx.match(words), test_words)
		
		# no deletions allowed
		apx = Apse.Approx("perl", dlt=0)
		test_words = "appeal hyperbola merlin parlance pearl perk superappeal superlative".split()
		self.assertEqual(apx.match(words), test_words)

		# no substitutions allowed
		apx = Apse.Approx("perl",sub=0)
		test_words = "dispel erlangen hyperbola merlin pearl perk superappeal superlative".split()
		self.assertEqual(apx.match(words), test_words)
		
		# maximum 2 edit distance
		apx = Apse.Approx("perl",edit=2)
		test_words = "aberrant accelerate appeal dispel erlangen felicity gibberish hyperbola iterate legerdemain merlin mermaid oatmeal park parlance Pearl pearl perk petal superappeal superlative supple twirl zealous ".split()
		self.assertEqual(apx.match(words), test_words)
		
		# ignore cases
		apx = Apse.Approx("perl", ignore_case=True)
		test_words = "appeal dispel erlangen hyperbola merlin parlance Pearl pearl perk superappeal superlative".split()
		self.assertEqual(apx.match(words), test_words)
	
		# maximum 20% of changes
		test = "0123456789"
		apx = Apse.Approx("012345678x", edit=0.1)
		self.assertEqual(apx.match(test), test)
		
		apx = Apse.Approx("01234567xx", edit=0.1)
		self.assertEqual(apx.match(test), None)
		
		apx = Apse.Approx("01234567xx", edit=0.2)
		self.assertEqual(apx.match(test), test)
		
		apx = Apse.Approx("0xxxxxxxxx", edit=0.8)
		self.assertEqual(apx.match(test), None)
		
		apx = Apse.Approx("xxxxxxxxxx", edit=0.99)
		self.assertEqual(apx.match(test), test)
		
if __name__=="__main__":
	unittest.main()
	
